{% extends 'allianceauth/base.html' %}
{% load i18n %}
{% block page_title %}{% trans "Alliance Toolbox!" %}{% endblock %}
{% block extra_css %}
{% include 'bundles/datatables-css.html' %}
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
 <style>
.flex-container {
    display: flex;
    flex-direction: row;
    height: 100%;
    align-items: center;
    justify-content: center;
}
.flex-wrap {
    display: -webkit-flex; /* Safari */
    -webkit-flex-wrap: wrap; /* Safari 6.1+ */
    display: flex;
    flex-wrap: wrap;
}
.flex-item {
    padding: 8px;
    margin: 4px;
    border-radius: 15px; /* 5px rounded corners */
    border-width: 1px;
    border-style: solid;
    border-color: #555;
}
.form-control {
    margin: 2px;
}


</style>

{% endblock extra_css %}
{% block content %}
    <div class="col-lg-12">
        <div class="col-lg-10 col-lg-offset-1 container">
             <!--{%if show_menu %}
            {% if perms.alliancetools.add_moonextractevent or perms.alliancetools.add_alliancecontact or perms.alliancetools.add_moonextractevent or perms.alliancetools.add_poco or perms.alliancetools.add_structure%}<h4> </h4>
            <nav class="navbar navbar-default">
                <div class="container-fluid">
                   <ul class="nav navbar-nav ">
                       {% if perms.alliancetools.add_alliancetoolcharacter %}<li><a href="{% url 'alliancetools:add_char' %}">{% trans "Add All Token" %}</a></li>{% endif %}
                       {% if perms.alliancetools.add_poco %}<li><a href="{% url 'alliancetools:add_poco' %}">{% trans "Add Poco Token" %}</a></li>{% endif %}
                       {% if perms.alliancetools.add_moonextractevent %}<li><a href="{% url 'alliancetools:add_moons' %}">{% trans "Add Moon Token" %}</a></li>{% endif %}
                       {% if perms.alliancetools.add_alliancecontact %}<li><a href="{% url 'alliancetools:add_contacts' %}">{% trans "Add Contacts Token" %}</a></li>{% endif %}
                       {% if perms.alliancetools.add_structure %}<li><a href="{% url 'alliancetools:add_structs' %}">{% trans "Add Structure Token" %}</a></li>{% endif %}
                       {% if perms.alliancetools.add_corpasset %}<li><a href="{% url 'alliancetools:add_assets' %}">{% trans "Add Asset Token" %}</a></li>{% endif %}
                    </ul>
                    {% if perms.alliancetoolbox.admin_alliance_tools %}
                    <ul class="nav navbar-nav navbar-right">
                        <li class="dropdown" style="margin-right: 5px">
                            <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="false"> <span class="fa fa-arrow-down"></span> WIP Pages </a>
                            <ul class="dropdown-menu">
                                <li><a href="{% url 'alliancetools:fuel' %}">{% trans "Fuel Calcs" %}</a></li>
                                <li><a href="{% url 'alliancetools:observers' %}">{% trans "Moon Observers" %}</a></li>
                                <li><a href="{% url 'alliancetools:contracts' %}">{% trans "Public Contracts" %}</a></li>
                                <li><a href="{% url 'alliancetools:str_txfr' %}">{% trans "Structure Txfrs" %}</a></li>
                                <li><a href="{% url 'alliancetools:structure_links' %}">{% trans "DotLan Links" %}</a></li>
                            </ul>
                        </li>
                    </ul>{% endif %}
                </div>
            </nav>{% endif %}{% endif %}-->

            {% block at_block %}{% endblock %}
        </div>

    </div>
{% endblock %}
