# Generated by Django 3.2.5 on 2021-09-06 09:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('moons', '0014_invoicerecord_tax_dump'),
    ]

    operations = [
        migrations.AddField(
            model_name='invoicerecord',
            name='total_mined',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=20),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='invoicerecord',
            name='total_taxed',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=20),
            preserve_default=False,
        ),
    ]
