# Generated by Django 3.2.5 on 2021-08-30 11:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('moons', '0011_oretax_tax'),
    ]

    operations = [
        migrations.RenameField(
            model_name='oretaxrates',
            old_name='excptional_rate',
            new_name='exceptional_rate',
        ),
    ]
