# Generated by Django 3.2.5 on 2021-08-30 11:12

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('moons', '0010_miningobservation_moon'),
    ]

    operations = [
        migrations.AddField(
            model_name='oretax',
            name='tax',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='tax_rate', to='moons.oretaxrates'),
            preserve_default=False,
        ),
    ]
