# Generated by Django 3.2.5 on 2021-08-27 10:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0058_auto_20210808_0635'),
        ('eveonline', '0014_auto_20210105_1413'),
        ('moons', '0007_miningtax_oreprice_oretax_oretaxrates'),
    ]

    operations = [
        migrations.AlterField(
            model_name='miningtax',
            name='constellation',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='tax_constellation', to='corptools.mapconstellation'),
        ),
        migrations.AlterField(
            model_name='miningtax',
            name='corp',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='moon_mining_tax', to='eveonline.evecorporationinfo'),
        ),
        migrations.AlterField(
            model_name='miningtax',
            name='moon',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='tax_moon', to='corptools.mapsystemmoon'),
        ),
        migrations.AlterField(
            model_name='miningtax',
            name='region',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='tax_region', to='corptools.mapregion'),
        ),
        migrations.AlterField(
            model_name='miningtax',
            name='system',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='tax_system', to='corptools.mapsystem'),
        ),
    ]
