# Generated by Django 3.1.1 on 2020-12-05 06:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('moons', '0002_auto_20201128_1356'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='miningobservation',
            name='id',
        ),
        migrations.AddField(
            model_name='miningobservation',
            name='frack_pk',
            field=models.CharField(default=None, max_length=50, primary_key=True, serialize=False),
            preserve_default=False,
        ),
    ]
