# Generated by Django 3.1.1 on 2020-12-05 06:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('moons', '0003_auto_20201205_0606'),
    ]

    operations = [
        migrations.RenameField(
            model_name='miningobservation',
            old_name='frack_pk',
            new_name='ob_pk',
        ),
    ]
