# Generated by Django 3.2.5 on 2021-08-22 12:22

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0014_auto_20210105_1413'),
        ('corptools', '0058_auto_20210808_0635'),
        ('moons', '0006_miningobservation_structure'),
    ]

    operations = [
        migrations.CreateModel(
            name='OreTaxRates',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tag', models.CharField(default='Mining Tax', max_length=500)),
                ('refine_rate', models.DecimalField(decimal_places=2, default=87.5, max_digits=5)),
                ('ore_rate', models.DecimalField(decimal_places=2, max_digits=5)),
                ('ubiquitous_rate', models.DecimalField(decimal_places=2, max_digits=5)),
                ('common_rate', models.DecimalField(decimal_places=2, max_digits=5)),
                ('uncommon_rate', models.DecimalField(decimal_places=2, max_digits=5)),
                ('rare_rate', models.DecimalField(decimal_places=2, max_digits=5)),
                ('excptional_rate', models.DecimalField(decimal_places=2, max_digits=5)),
            ],
        ),
        migrations.CreateModel(
            name='OreTax',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('price', models.DecimalField(decimal_places=2, max_digits=20)),
                ('last_update', models.DateTimeField(auto_now=True)),
                ('item', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='ore_tax', to='corptools.eveitemtype')),
            ],
        ),
        migrations.CreateModel(
            name='OrePrice',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('price', models.DecimalField(decimal_places=2, max_digits=20)),
                ('last_update', models.DateTimeField(auto_now=True)),
                ('item', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='ore_price', to='corptools.eveitemtype')),
            ],
        ),
        migrations.CreateModel(
            name='MiningTax',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('use_variable_tax', models.BooleanField(default=False)),
                ('flat_tax_rate', models.DecimalField(blank=True, decimal_places=2, default=None, max_digits=5, null=True)),
                ('region', models.CharField(blank=True, default=None, max_length=50, null=True)),
                ('constellation', models.CharField(blank=True, default=None, max_length=50, null=True)),
                ('system', models.CharField(blank=True, default=None, max_length=50, null=True)),
                ('moon', models.CharField(blank=True, default=None, max_length=50, null=True)),
                ('rank', models.IntegerField(blank=True, default=0, null=True)),
                ('corp', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='moon_mining_tax', to='eveonline.evecorporationinfo')),
                ('tax_rate', models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, to='moons.oretaxrates')),
            ],
        ),
    ]
