# Generated by Django 3.2.5 on 2021-09-04 10:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('moons', '0013_auto_20210904_0948'),
    ]

    operations = [
        migrations.AddField(
            model_name='invoicerecord',
            name='tax_dump',
            field=models.TextField(default=0),
            preserve_default=False,
        ),
    ]
