# Generated by Django 3.2.5 on 2021-09-04 09:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0059_invtypematerials_met_type'),
        ('moons', '0012_rename_excptional_rate_oretaxrates_exceptional_rate'),
    ]

    operations = [
        migrations.CreateModel(
            name='InvoiceRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateTimeField()),
                ('end_date', models.DateTimeField()),
                ('ore_prices', models.TextField()),
            ],
        ),
        migrations.AddField(
            model_name='miningobservation',
            name='observing_corporation',
            field=models.ForeignKey(default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='corptools.corporationaudit'),
        ),
    ]
