# Generated by Django 3.1.1 on 2020-11-28 13:56

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('moons', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='miningobservation',
            old_name='char',
            new_name='character_name',
        ),
        migrations.RemoveField(
            model_name='miningobservation',
            name='observer',
        ),
        migrations.AddField(
            model_name='miningobservation',
            name='frack',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='moons.moonfrack'),
            preserve_default=False,
        ),
    ]
